# 概括
这是一个自己总结的常用的python库
安装地址为:
    pip install -i https://test.pypi.org/simple/ zqpy
    或
    pip install zqpy
    若是更新
    pip install --upgrade zqpy

## 说明
setup.py 参考git  https://github.com/navdeep-G/setup.py

### 参数说明
Fun.png
### 错误反馈
QQ:1620829248